# GUNDALA PROJECT

EPP Library

## Installing

At the time g only undala support Python3 or newer.

``` bash
pip3 install -e .
```

## Configuration Example

Duplicate file config.py.example to config.py

``` bash
cp example/config.py.example example/config.py
```

## Running

``` bash
python3 example/file_example.py
```
